**Example 1: DeleteVpcEndPoint**

删除终端节点

Input: 

```
tccli vpc DeleteVpcEndPoint --cli-unfold-argument  \
    --EndPointId vpce-h0fk8lfc
```

Output: 
```
{
    "Response": {
        "RequestId": "7e6f5074-e4a2-4bb6-9cac-d2357a00896f"
    }
}
```

